@@ -2,8 +2,7 @@ using BenchmarkTools
 using LinearAlgebra
 using SparseArrays
 using QuantumToolbox
-using OrdinaryDiffEq
-using LinearSolve
+using SciMLBase: EnsembleSerial, EnsembleThreads
 
 BLAS.set_num_threads(1)
 
@@ -11,12 +10,14 @@ const SUITE = BenchmarkGroup()
 
 include("correlations_and_spectrum.jl")
 include("dynamical_fock_dimension.jl")
+include("dynamical_shifted_fock.jl")
 include("eigenvalues.jl")
 include("steadystate.jl")
 include("timeevolution.jl")
 
 benchmark_correlations_and_spectrum!(SUITE)
 benchmark_dfd!(SUITE)
+benchmark_dsf!(SUITE)
 benchmark_eigenvalues!(SUITE)
 benchmark_steadystate!(SUITE)
 benchmark_timeevolution!(SUITE)
