@@ -202,8 +202,8 @@
         @test (a2 + 2).data == a2.data + 2 * I
         @test a2 * 2 == 2 * a2
 
-        zero_like = zero(a2)
-        iden_like = one(a3)
+        zero_like = qzero_like(a2)
+        iden_like = qeye_like(a3)
         zero_array = spzeros(ComplexF64, 100, 100)
         iden_array = sparse(1:100, 1:100, ones(ComplexF64, 100))
         @test zero_like == Qobj(zero_array, type = a2.type, dims = a2.dims)
